@@ -2,7 +2,9 @@ import contextlib
 import json
 import logging
 from asyncio import AbstractEventLoop
-from typing import Any, Dict, Optional, Text
+from typing import Any, Dict, Optional, Text, Generator
+
+from sqlalchemy.orm import Session
 
 from rasa.core.brokers.broker import EventBroker
 from rasa.utils.endpoints import EndpointConfig
@@ -17,11 +19,13 @@ class SQLEventBroker(EventBroker):
 
     """
 
-    from sqlalchemy.ext.declarative import declarative_base
+    from sqlalchemy.ext.declarative import declarative_base, DeclarativeMeta
 
-    Base = declarative_base()
+    Base: DeclarativeMeta = declarative_base()
 
     class SQLBrokerEvent(Base):
+        """ORM which represents a row in the `events` table."""
+
         from sqlalchemy import Column, Integer, String, Text
 
         __tablename__ = "events"
@@ -37,7 +41,7 @@ class SQLEventBroker(EventBroker):
         db: Text = "events.db",
         username: Optional[Text] = None,
         password: Optional[Text] = None,
-    ):
+    ) -> None:
         from rasa.core.tracker_store import SQLTrackerStore
         import sqlalchemy.orm
 
@@ -61,7 +65,7 @@ class SQLEventBroker(EventBroker):
         return cls(host=broker_config.url, **broker_config.kwargs)
 
     @contextlib.contextmanager
-    def session_scope(self):
+    def session_scope(self) -> Generator[Session, None, None]:
         """Provide a transactional scope around a series of operations."""
         session = self.sessionmaker()
         try:
