@@ -1,6 +1,8 @@
 import logging
 
 from typing import Any, Dict, List, NoReturn, Optional, Text, Tuple, Type
+
+from tensorflow.python.eager.wrap_function import WrappedFunction
 from tqdm import tqdm
 import os
 
@@ -45,7 +47,10 @@ ORIGINAL_TF_HUB_MODULE_URL = (
 
 # Warning: This URL is only intended for running pytests on ConveRT
 # related components. This URL should not be allowed to be used by the user.
-RESTRICTED_ACCESS_URL = "https://storage.googleapis.com/continuous-integration-model-storage/convert_tf2.tar.gz"
+RESTRICTED_ACCESS_URL = (
+    "https://storage.googleapis.com/continuous-"
+    "integration-model-storage/convert_tf2.tar.gz"
+)
 
 
 class ConveRTFeaturizer(DenseFeaturizer):
@@ -83,11 +88,15 @@ class ConveRTFeaturizer(DenseFeaturizer):
 
         self.module = train_utils.load_tf_hub_model(self.model_url)
 
-        self.tokenize_signature = self._get_signature("tokenize", self.module)
-        self.sequence_encoding_signature = self._get_signature(
+        self.tokenize_signature: WrappedFunction = self._get_signature(
+            "tokenize", self.module
+        )
+        self.sequence_encoding_signature: WrappedFunction = self._get_signature(
             "encode_sequence", self.module
         )
-        self.sentence_encoding_signature = self._get_signature("default", self.module)
+        self.sentence_encoding_signature: WrappedFunction = self._get_signature(
+            "default", self.module
+        )
 
     @staticmethod
     def _validate_model_files_exist(model_directory: Text) -> None:
@@ -106,10 +115,10 @@ class ConveRTFeaturizer(DenseFeaturizer):
         for file_path in files_to_check:
             if not os.path.exists(file_path):
                 raise RasaException(
-                    f"""File {file_path} does not exist.
-                        Re-check the files inside the directory {model_directory}.
-                        It should contain the following model
-                        files - [{", ".join(files_to_check)}]"""
+                    f"File {file_path} does not exist. "
+                    f"Re-check the files inside the directory {model_directory}. "
+                    f"It should contain the following model "
+                    f"files - [{', '.join(files_to_check)}]"
                 )
 
     def _get_validated_model_url(self) -> Text:
@@ -126,42 +135,44 @@ class ConveRTFeaturizer(DenseFeaturizer):
 
         if not model_url:
             raise RasaException(
-                f"""Parameter "model_url" was not specified in the configuration
-                of "{ConveRTFeaturizer.__name__}". It is mandatory to pass a value for this parameter.
-                You can either use a community hosted URL of the model
-                or if you have a local copy of the model, pass the
-                path to the directory containing the model files."""
+                f"Parameter 'model_url' was not specified in the configuration "
+                f"of '{ConveRTFeaturizer.__name__}'. "
+                f"It is mandatory to pass a value for this parameter. "
+                f"You can either use a community hosted URL of the model "
+                f"or if you have a local copy of the model, pass the "
+                f"path to the directory containing the model files."
             )
 
         if model_url == ORIGINAL_TF_HUB_MODULE_URL:
             # Can't use the originally hosted URL
             raise RasaException(
-                f"""Parameter "model_url" of "{ConveRTFeaturizer.__name__}" was
-                set to "{model_url}" which does not contain the model any longer.
-                You can either use a community hosted URL or if you have a
-                local copy of the model, pass the path to the directory
-                containing the model files."""
+                f"Parameter 'model_url' of '{ConveRTFeaturizer.__name__}' was "
+                f"set to '{model_url}' which does not contain the model any longer. "
+                f"You can either use a community hosted URL or if you have a "
+                f"local copy of the model, pass the path to the directory "
+                f"containing the model files."
             )
 
         if model_url == RESTRICTED_ACCESS_URL:
             # Can't use the URL that is reserved for tests only
             raise RasaException(
-                f"""Parameter "model_url" of "{ConveRTFeaturizer.__name__}" was
-                set to "{model_url}" which is strictly reserved for pytests of Rasa Open Source only.
-                Due to licensing issues you are not allowed to use the model from this URL.
-                You can either use a community hosted URL or if you have a
-                local copy of the model, pass the path to the directory
-                containing the model files."""
+                f"Parameter 'model_url' of '{ConveRTFeaturizer.__name__}' was "
+                f"set to '{model_url}' which is strictly reserved for pytests of "
+                f"Rasa Open Source only. Due to licensing issues you are "
+                f"not allowed to use the model from this URL. "
+                f"You can either use a community hosted URL or if you have a "
+                f"local copy of the model, pass the path to the directory "
+                f"containing the model files."
             )
 
         if os.path.isfile(model_url):
             # Definitely invalid since the specified path should be a directory
             raise RasaException(
-                f"""Parameter "model_url" of "{ConveRTFeaturizer.__name__}" was
-                set to the path of a file which is invalid. You
-                can either use a community hosted URL or if you have a
-                local copy of the model, pass the path to the directory
-                containing the model files."""
+                f"Parameter 'model_url' of '{ConveRTFeaturizer.__name__}' was "
+                f"set to the path of a file which is invalid. You "
+                f"can either use a community hosted URL or if you have a "
+                f"local copy of the model, pass the path to the directory "
+                f"containing the model files."
             )
 
         if rasa.nlu.utils.is_url(model_url):
@@ -176,10 +187,10 @@ class ConveRTFeaturizer(DenseFeaturizer):
             return os.path.abspath(model_url)
 
         raise RasaException(
-            f"""{model_url} is neither a valid remote URL nor a local directory.
-            You can either use a community hosted URL or if you have a
-            local copy of the model, pass the path to
-            the directory containing the model files."""
+            f"{model_url} is neither a valid remote URL nor a local directory. "
+            f"You can either use a community hosted URL or if you have a "
+            f"local copy of the model, pass the path to "
+            f"the directory containing the model files."
         )
 
     @staticmethod
